@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_001/lib/Perl/Critic/Utils/McCabe.pm $
-#     $Date: 2010-01-16 11:48:41 -0800 (Sat, 16 Jan 2010) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.105_02/lib/Perl/Critic/Utils/McCabe.pm $
+#     $Date: 2010-01-23 21:02:32 -0800 (Sat, 23 Jan 2010) $
 #   $Author: thaljef $
-# $Revision: 3748 $
+# $Revision: 3762 $
 ##############################################################################
 
 package Perl::Critic::Utils::McCabe;
@@ -19,7 +19,7 @@ use base 'Exporter';
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.105_01';
+our $VERSION = '1.105_02';
 
 #-----------------------------------------------------------------------------
 
@@ -156,7 +156,7 @@ Provides approximations of McCabe scores.  The McCabe score of a set
 of code describes the number of possible paths through it.  The
 functions here approximate the McCabe score by summing the number of
 conditional statements and operators within a set of code.  See
-L<http://www.sei.cmu.edu/str/descriptions/cyclomatic_body.html> for
+L<http://en.wikipedia.org/wiki/Cyclomatic_complexity> for
 some discussion about the McCabe number and other complexity metrics.
 
 
